Enum bdk_cli::CliSubCommand [−][src]
pub enum CliSubCommand {
Wallet {
wallet_opts: WalletOpts,
subcommand: WalletSubCommand,
},
Key {
subcommand: KeySubCommand,
},
Compile {
policy: String,
script_type: String,
},
Repl {
wallet_opts: WalletOpts,
},
}Expand description
CLI sub-commands
The top level sub-commands, each may have different required options. For
instance CliSubCommand::Wallet requires WalletOpts with a required descriptor but
CliSubCommand::Key sub-command does not. CliSubCommand::Repl also requires
WalletOpts and a descriptor because in this mode both WalletSubCommand and
KeySubCommand sub-commands are available.
Variants
Wallet options and sub-commands
Fields of Wallet
wallet_opts: WalletOptssubcommand: WalletSubCommandKey management sub-commands
Fields of Key
subcommand: KeySubCommandCompile a miniscript policy to an output descriptor
Fields of Compile
Enter REPL command loop mode
Fields of Repl
wallet_opts: WalletOptsTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Builds the struct from clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic. Read more
Builds the struct from the command line arguments (std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program. Read more
Builds the struct from the command line arguments (std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you. Read more
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making.
Print the error message and quit the program in case of failure. Read more
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making. Read more