Enum bdk_cli::OnlineWalletSubCommand
source · [−]Expand description
Online Wallet sub-command
CliSubCommand::Wallet sub-commands that require a blockchain client and network connection.
These sub-commands use a provided descriptor, locally cached wallet information, and require a
blockchain client and network connection.
Variants
Sync
Syncs with the chosen blockchain server
Broadcast
Fields
Broadcasts a transaction to the network. Takes either a raw transaction or a PSBT to extract