Struct bdk_cli::WalletOpts
source · [−]pub struct WalletOpts {
pub wallet: Option<String>,
pub verbose: bool,
pub descriptor: String,
pub change_descriptor: Option<String>,
pub electrum_opts: ElectrumOpts,
pub proxy_opts: ProxyOpts,
}Expand description
Wallet options
The wallet options required for all CliSubCommand::Wallet or CliSubCommand::Repl
sub-commands. These options capture wallet descriptor and blockchain client information. The
blockchain client details are only used for OnlineWalletSubCommands.
Example
let cli_args = vec!["wallet",
"--descriptor", "wpkh(tpubEBr4i6yk5nf5DAaJpsi9N2pPYBeJ7fZ5Z9rmN4977iYLCGco1VyjB9tvvuvYtfZzjD5A8igzgw3HeWeeKFmanHYqksqZXYXGsw5zjnj7KM9/44'/1'/0'/0/*)"];
// to get WalletOpt from OS command line args use:
// let wallet_opt = WalletOpt::from_args();
let wallet_opts = WalletOpts::from_iter(&cli_args);
let expected_wallet_opts = WalletOpts {
wallet: None,
verbose: false,
descriptor: "wpkh(tpubEBr4i6yk5nf5DAaJpsi9N2pPYBeJ7fZ5Z9rmN4977iYLCGco1VyjB9tvvuvYtfZzjD5A8igzgw3HeWeeKFmanHYqksqZXYXGsw5zjnj7KM9/44'/1'/0'/0/*)".to_string(),
change_descriptor: None,
#[cfg(feature = "electrum")]
electrum_opts: ElectrumOpts {
timeout: None,
server: "ssl://electrum.blockstream.info:60002".to_string(),
stop_gap: 10
},
#[cfg(feature = "esplora")]
esplora_opts: EsploraOpts {
server: "https://blockstream.info/testnet/api/".to_string(),
timeout: 5,
stop_gap: 10,
conc: 4
},
#[cfg(feature = "compact_filters")]
compactfilter_opts: CompactFilterOpts{
address: vec!["127.0.0.1:18444".to_string()],
conn_count: 4,
skip_blocks: 0,
},
#[cfg(feature = "rpc")]
rpc_opts: RpcOpts{
address: "127.0.0.1:18443".to_string(),
basic_auth: ("user".to_string(), "password".to_string()),
skip_blocks: None,
cookie: None,
},
#[cfg(any(feature="compact_filters", feature="electrum", feature="esplora"))]
proxy_opts: ProxyOpts{
proxy: None,
proxy_auth: None,
retries: 5,
},
};
assert_eq!(expected_wallet_opts, wallet_opts);Fields
wallet: Option<String>Selects the wallet to use
verbose: boolAdds verbosity, returns PSBT in JSON format alongside serialized, displays expanded objects
descriptor: StringSets the descriptor to use for the external addresses
change_descriptor: Option<String>Sets the descriptor to use for internal addresses
electrum_opts: ElectrumOptsproxy_opts: ProxyOptsTrait Implementations
sourceimpl Clone for WalletOpts
impl Clone for WalletOpts
sourcefn clone(&self) -> WalletOpts
fn clone(&self) -> WalletOpts
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for WalletOpts
impl Debug for WalletOpts
sourceimpl PartialEq<WalletOpts> for WalletOpts
impl PartialEq<WalletOpts> for WalletOpts
sourcefn eq(&self, other: &WalletOpts) -> bool
fn eq(&self, other: &WalletOpts) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &WalletOpts) -> bool
fn ne(&self, other: &WalletOpts) -> bool
This method tests for !=.
sourceimpl StructOpt for WalletOpts
impl StructOpt for WalletOpts
sourcefn from_clap(matches: &ArgMatches<'_>) -> Self
fn from_clap(matches: &ArgMatches<'_>) -> Self
Builds the struct from clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic. Read more
sourcefn from_args() -> Self
fn from_args() -> Self
Builds the struct from the command line arguments (std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program. Read more
sourcefn from_args_safe() -> Result<Self, Error>
fn from_args_safe() -> Result<Self, Error>
Builds the struct from the command line arguments (std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you. Read more
sourcefn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making.
Print the error message and quit the program in case of failure. Read more
sourcefn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making. Read more
impl StructuralPartialEq for WalletOpts