Enum bdk_cli::KeySubCommand[][src]

pub enum KeySubCommand {
    Generate {
        word_count: usize,
        password: Option<String>,
    },
    Restore {
        mnemonic: String,
        password: Option<String>,
    },
    Derive {
        xprv: ExtendedPrivKey,
        path: DerivationPath,
    },
}
Key sub-command

Provides basic key operations that are not related to a specific wallet such as generating a new random master extended key or restoring a master extended key from mnemonic words.

These sub-commands are EXPERIMENTAL and should only be used for testing. Do not use this feature to create keys that secure actual funds on the Bitcoin mainnet.

Variants

Generate

Generates new random seed mnemonic phrase and corresponding master extended key

Fields of Generate

word_count: usize

Entropy level based on number of random seed mnemonic words

password: Option<String>

Seed password

Restore

Restore a master extended key from seed backup mnemonic words

Fields of Restore

mnemonic: String

Seed mnemonic words, must be quoted (eg. “word1 word2 …”)

password: Option<String>

Seed password

Derive

Derive a child key pair from a master extended key and a derivation path string (eg. “m/84’/1’/0’/0” or “m/84h/1h/0h/0”)

Fields of Derive

xprv: ExtendedPrivKey

Extended private key to derive from

path: DerivationPath

Path to use to derive extended public key from extended private key