Enum bdk_cli::OnlineWalletSubCommand [−][src]
pub enum OnlineWalletSubCommand {
Sync {
max_addresses: Option<u32>,
},
Broadcast {
psbt: Option<String>,
tx: Option<String>,
},
}Expand description
Online Wallet sub-command
CliSubCommand::Wallet sub-commands that require a blockchain client and network connection.
These sub-commands use a provided descriptor, locally cached wallet information, and require a
blockchain client and network connection.
Variants
Syncs with the chosen blockchain server
Broadcasts a transaction to the network. Takes either a raw transaction or a PSBT to extract
Fields of Broadcast