pub struct WalletOpts {
    pub wallet: Option<String>,
    pub verbose: bool,
    pub descriptor: String,
    pub change_descriptor: Option<String>,
    pub electrum_opts: ElectrumOpts,
    pub proxy_opts: ProxyOpts,
}
Wallet options

The wallet options required for all CliSubCommand::Wallet or CliSubCommand::Repl sub-commands. These options capture wallet descriptor and blockchain client information. The blockchain client details are only used for OnlineWalletSubCommands.

Example


let cli_args = vec!["wallet",
                     "--descriptor", "wpkh(tpubEBr4i6yk5nf5DAaJpsi9N2pPYBeJ7fZ5Z9rmN4977iYLCGco1VyjB9tvvuvYtfZzjD5A8igzgw3HeWeeKFmanHYqksqZXYXGsw5zjnj7KM9/44'/1'/0'/0/*)"];

// to get WalletOpt from OS command line args use:
// let wallet_opt = WalletOpt::from_args();

let wallet_opts = WalletOpts::from_iter(&cli_args);

let expected_wallet_opts = WalletOpts {
               wallet: None,
                    verbose: false,
               descriptor: "wpkh(tpubEBr4i6yk5nf5DAaJpsi9N2pPYBeJ7fZ5Z9rmN4977iYLCGco1VyjB9tvvuvYtfZzjD5A8igzgw3HeWeeKFmanHYqksqZXYXGsw5zjnj7KM9/44'/1'/0'/0/*)".to_string(),
               change_descriptor: None,
               #[cfg(feature = "electrum")]
               electrum_opts: ElectrumOpts {
                   timeout: None,
                   server: "ssl://electrum.blockstream.info:60002".to_string(),
                   stop_gap: 10
               },
               #[cfg(feature = "esplora")]
               esplora_opts: EsploraOpts {
                   server: "https://blockstream.info/testnet/api/".to_string(),
                   timeout: 5,
                   stop_gap: 10,
                   conc: 4
               },
               #[cfg(feature = "compact_filters")]
               compactfilter_opts: CompactFilterOpts{
                    address: vec!["127.0.0.1:18444".to_string()],
                    conn_count: 4,
                    skip_blocks: 0,
               },
               #[cfg(feature = "rpc")]
               rpc_opts: RpcOpts{
                    address: "127.0.0.1:18443".to_string(),
                    basic_auth: ("user".to_string(), "password".to_string()),
                    skip_blocks: None,
                    cookie: None,
               },
               #[cfg(any(feature="compact_filters", feature="electrum", feature="esplora"))]
                    proxy_opts: ProxyOpts{
                        proxy: None,
                        proxy_auth: None,
                        retries: 5,
               },
 };

assert_eq!(expected_wallet_opts, wallet_opts);

Fields

wallet: Option<String>

Selects the wallet to use

verbose: bool

Adds verbosity, returns PSBT in JSON format alongside serialized, displays expanded objects

descriptor: String

Sets the descriptor to use for the external addresses

change_descriptor: Option<String>

Sets the descriptor to use for internal addresses

electrum_opts: ElectrumOptsproxy_opts: ProxyOpts